@@ -1,4 +1,14 @@
-use std::io::{self};
+#![deny(warnings)]
+#![doc(test(attr(deny(warnings))))]
+#![doc(test(attr(allow(dead_code))))]
+#![doc(test(attr(allow(unused_variables))))]
+
+#![no_std]
+
+extern crate alloc;
+
+use alloc::boxed::Box;
+use errno_no_std::Errno;
 
 pub use tuifw_screen_base::*;
 
@@ -11,7 +21,7 @@ pub use tuifw_screen_base::*;
 /// It is impossible to garantee this conditions on a library level.
 /// So this unsafity should be propagated through all wrappers to the final application.
 #[cfg(windows)]
-pub unsafe fn init() -> io::Result<Box<dyn Screen>> {
+pub unsafe fn init() -> Result<Box<dyn Screen>, Errno> {
     Ok(Box::new(tuifw_screen_winapi::Screen::new()?) as _)
 }
 
@@ -24,6 +34,6 @@ pub unsafe fn init() -> io::Result<Box<dyn Screen>> {
 /// It is impossible to garantee this conditions on a library level.
 /// So this unsafity should be propagated through all wrappers to the final application.
 #[cfg(not(windows))]
-pub unsafe fn init() -> io::Result<Box<dyn Screen>> {
+pub unsafe fn init() -> Result<Box<dyn Screen>, Errno> {
     tuifw_screen_ncurses::init()
 }
